



# ---------------------------------------------------------------------
# Program: IntroR.R
#  Author: Siny Tsang
#    Date: Mon Jan 27 2014
#
#  Introduction to R
#  UVA Statlab Workshop
#  Thurs Jan 30 2014
#
# ---------------------------------------------------------------------
#  Note: 
#  This R script can be used together with the workshop slides.
#  All can be downloaded at:
#  http://static.lib.virginia.edu/statlab/materials/workshops/Intro_to_R.zip
#  or
#  people.virginia.edu/~st2sb/introR.html
#  
# ---------------------------------------------------------------------



# Using R as a calculator
15+10
12/6
.7*5



# R ignores spaces
12/6
12 / 6
.7*5
.7 * 5



# This is a comment. 
# When a # is placed somewhere on a line, 
# everything after the # is considered a comment 
# (including other #'s). 




# Store the number 22 in the object called "value"
value1 <- 22

# Store results of computation
value2 <- 22/7

# Type the name to view the stored object
value1
value2



# You can now do other things with the object.
value1 / 2



# Store the results into a new object.
new.value1 <- value1 / 2
new.value1



# Object names cannot begin with a number
value3 <- 100  # This is OK
3value <- 100  # This will not work

# Object names cannot have spaces
value 3 <- 100  # This will not work



# R is case sensitive
value3 <- 100  
value3

# This will not work
Value3



# Objects of the same name will be overwritten
value4 <- 5^2  
value4

value4 <- sqrt(100)
value4
#value4 is now overwritten



# Assign multiple values to an object, resulting in a vector.
my.vector1 <- c(1,3,2,2,4)
my.vector1
my.vector2 <- c(5,6,8,1,4)
my.vector2



# Operations are conducted on an element-by-element basis
my.vector1 + 2
my.vector1 + my.vector2



# Assign character values to an object, resulting in a character vector
my.names <- c("Rob", "Tess", "Megan", "Kevin", "Liam")
my.names



my.vector1



my.names



# Create a factor vector
my.factor <- factor(c(0, 1, 1, 0, 0), 
                    labels = c("Male", "Female"))
my.factor



# Use str() to identify object structures
str(my.vector1)
str(my.names)
str(my.factor)



# Create matrix using matrix()
# Combine the previously created vectors
my.matrix <- matrix(c(my.vector1, my.names, my.factor), 
                    ncol = 3)  # Matrix with 3 columns
my.matrix



# R forces data to be of one type
my.matrix
str(my.matrix)
# This is a character matrix



# Create dataframe with data.frame()
my.dat <- data.frame(Score = my.vector1, 
                     Names = my.names, 
                     Gender = my.factor)
my.dat



# data frames can have different types of data
str(my.dat)



# Retains character factors using stringsAsFactors=FALSE
my.dat1 <- data.frame(Score = my.vector1, 
                      Names = my.names, 
                      Gender = my.factor, 
                      stringsAsFactors = FALSE)
str(my.dat1)



# Lists can have different data types & lengths
my.list <- list(Numeric = my.vector1, 
                Character = my.names, 
                Numeric.new = c(1.5, 2.8, 3.3))
my.list



# Lists assume elements are vectors
str(my.list)



# Generate consequtive numbers: use colon
1:10



# Generate consequtive numbers: use seq()
seq(1, 5)
seq(1, 5, by = .5)



# Generate repeat number of sequence
# repeat "x" 5 times
rep("x", 5)  
# repeat c(1:5) 3 times
rep(c(1:5), 3) 
# repeat seq(1,3 by=.5) 2 times
rep(seq(1, 3, by = .5), 2) 



# USe paste() to combine characters & sequence
paste("condition", seq(1:5), sep="")
paste("condition", c("A","B","C"), sep=".")



x <- rep(c(1:3), 2)
x
# Logical Operators1
x >= 3



# Logical Operators2
x == 1
x != 1



# Logical Operators3
x
x == 1 & x == 2
x == 1 | x == 2


# list everything in my workspace
ls()
# remove my.dat object
rm(my.dat)
# my.dat is no longer in my workspace
ls()



mean(x)  # mean
sd(x)  # standard deviation
summary(x)  # Basic descriptive statistics
min(x)  # Minimum value



## # Function name known
help(matrix)
?matrix

## # Function name unknown
help.search("regression")
??anova



## # Install packages
install.packages("car")
## 
## # Load packages: the following two lines are the same
library(car)
require(car)



# View all installed packages
library()
# View currently loaded packages
search()



# Load Vocab data
data(Vocab)



# What are the dimensions of the data frame?
dim(Vocab)
# rows x columns



# What are the variables in the data?
names(Vocab)



# Beginning of the data
head(Vocab)
# End of the data
tail(Vocab)



x
# Select the first 3 elements
x[1:3]
# Select the 4th and 5th elements
x[c(4,5)]
# Unselect the 4th and 5th elements
x[-c(4,5)]



head(Vocab)



# Select the element in row 1, column 3
Vocab[1,3]
# Select elements in rows 2 & 3, columns 2, 3, 4
Vocab[2:3, 2:4]



# Subset the first 5 rows of the data
vocab.10 <- Vocab[1:10, ]
vocab.10



# Subset data where sex==Female
vocab.10.female <- vocab.10[which(vocab.10$sex == "Female"), ]
vocab.10.female



# Show column names
colnames(vocab.10) # or
names(vocab.10)



# Assign new variable names
names(vocab.10) <- c("time", "gender", "edu", "vocab")
names(vocab.10)



# Print edu column
vocab.10[ ,3]
vocab.10$edu



# Original data
head(vocab.10, 5)



# Sort data by education
vocab.10.edu <- vocab.10[order(vocab.10$edu), ]
head(vocab.10.edu, 5)



# Sort data by education
vocab.10.edu <- vocab.10[order(vocab.10$edu, 
                               decreasing = TRUE), ]
head(vocab.10.edu, 5)



# Create new variable "vocab" * 10
vocab.10.edu$vocab10 <- vocab.10.edu$vocab * 10

head(vocab.10.edu, 5)



# Mean of Education
mean(Vocab$education)
# Standard Deviation of Education
sd(Vocab$education)



# Mean & Standard Deviation of Education
with(Vocab, c(mean(education), sd(education)))



## # install 'psych' package
install.packages("psych")



## # install 'psych' package
library(psych)  # or
require(psych)



# Summary statistics, describe() in 'psych' package
describe(Vocab)



# Plot histogram of vocabulary
hist(Vocab$vocabulary, breaks = 10, col = "cyan")



# Summary statistics, describe.by() in 'psych' package
vocab.summary <- describeBy(Vocab, group = Vocab$sex, mat=TRUE)
vocab.summary[1:4, ]  # Show only the first 2 variables



# Plot bar chart
barplot(table(Vocab$education), main="Education Distribution", 
     xlab="Education Level", col = "purple")



# Frequency Table 
my.table <- with(Vocab, table(sex, year)) 
my.table 



# Plot bar chart by group
barplot(table(Vocab$sex, Vocab$vocabulary), 
        main = "Vocabulary by gender",
        xlab = "Vocabulary",
        col = c("lightblue", "pink"),
        legend = c("Male", "Female"),
        beside=TRUE
        )



data(sat.act)
# 2-group t-test
with(sat.act, t.test(SATQ ~ gender))



with(sat.act, t.test(SATQ ~ gender))



# Boxplot 
boxplot(SATQ ~ gender, data = sat.act, 
        main = "SAT Quantitative by Gender", 
        xlab = "Gender",
        ylab = "SAT Quantitative Score"
)



# Correlation Test
cor.test(x = sat.act$SATQ, y = sat.act$SATV,
         alternative="two.sided", method="pearson"
         )



# Scatterplot
with(sat.act, 
     plot(SATV, SATQ, main="SAT Verbal by Quantitative Score", 
     xlab="SAT Verbal", ylab="SAT QUantitative ", pch=20, col = "blue"
     )
)



# Linear Regression lm()
lm.1 <- lm(SATQ ~ SATV, data = sat.act)
summary(lm.1)



summary(lm.1)



# Scatterplot
with(sat.act, 
     plot(SATV, SATQ, main="SAT Verbal by Quantitative Score", 
     xlab="SAT Verbal", ylab="SAT QUantitative ", pch=20, col = "blue"
     )
)
# Add regression line
abline(lm(SATQ ~ SATV, data = sat.act), col = "red")



# Data from internet
Dosage <- read.table("http://personality-project.org/r/datasets/R.appendix2.text", 
                     header = TRUE)



head(Dosage)



# View functions in the foreign package
library(help = foreign)


# Set working directory: setwd()
# For Windows:
# setwd("C:/Users/My Name/Documents/R Stuff") # or
# setwd("C:\\Users\\My Name\\Documents\\R Stuff")
# For Mac:
# setwd("/Users/My Name/Document/R Stuff/")

# Get working directory
get()  # should return the directory which you are currently in


# write.table() default
write.table(Dosage, "NewDosage.txt")
# Removes row names and quotes
write.table(Dosage, "NewDosage_new.txt")



# write.csv() default
write.csv(Dosage, "NewDosage.csv")

# You should see 3 new files in your working directory


set.seed(1234)
# Generate some data
x <- rnorm(100)
hist(x, probability = TRUE, col = "blue")
lines(density(x), col = "red")



# Determine graphic output
pdf("randomhistogram.pdf")
hist(x, probability = TRUE, col = "blue")
lines(density(x), col = "red")
dev.off()        # Turn off graphic output

# The file: randomhistorgm.pdf is saved into your working directory
